from datetime import datetime, timedelta
from typing import Any

from jose import jwt
from passlib.context import CryptContext

from service.config import settings
from service.constants.security import ALGORITHM

pwd_context = CryptContext(schemes=["bcrypt"], deprecated="auto")


def create_access_token(subject: str | Any) -> str:
    expire = datetime.utcnow() + timedelta(days=settings.token_expiration_days)
    to_encode = {"exp": expire, "sub": str(subject)}
    encoded_jwt = jwt.encode(to_encode, settings.secret_key, algorithm=ALGORITHM)
    return encoded_jwt


def verify_password(plain_password: str, hashed_password: str) -> bool:
    return pwd_context.verify(plain_password, hashed_password)


def get_password_hash(password: str) -> str:
    return pwd_context.hash(password)
